pub struct AskClient { /* private fields */ }Expand description
High-level client for talon ask planning and synthesis.
Implementations
Sourceimpl AskClient
impl AskClient
Sourcepub fn new(chat: ChatClient) -> Self
pub fn new(chat: ChatClient) -> Self
Builds an ask client from an existing chat client.
Sourcepub const fn with_stage_clients(
planning_chat: ChatClient,
synthesis_chat: ChatClient,
) -> Self
pub const fn with_stage_clients( planning_chat: ChatClient, synthesis_chat: ChatClient, ) -> Self
Builds an ask client with distinct planner and synthesis clients.
Sourcepub fn plan_queries_detailed(
&self,
question: &str,
limit: u8,
) -> Result<AskPlan, AskError>
pub fn plan_queries_detailed( &self, question: &str, limit: u8, ) -> Result<AskPlan, AskError>
Sourcepub fn synthesize(
&self,
question: &str,
queries: &[String],
sources: &[AskSource],
) -> Result<String, AskError>
pub fn synthesize( &self, question: &str, queries: &[String], sources: &[AskSource], ) -> Result<String, AskError>
Sourcepub fn synthesize_detailed(
&self,
question: &str,
queries: &[String],
sources: &[AskSource],
) -> Result<AskSynthesis, AskError>
pub fn synthesize_detailed( &self, question: &str, queries: &[String], sources: &[AskSource], ) -> Result<AskSynthesis, AskError>